@@ -54,6 +54,7 @@ sorted_classifiers: List[str] = [
     "Environment :: GPU :: NVIDIA CUDA :: 12",
     "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.0",
     "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.1",
+    "Environment :: GPU :: NVIDIA CUDA :: 12 :: 12.2",
     "Environment :: Handhelds/PDA's",
     "Environment :: MacOS X",
     "Environment :: MacOS X :: Aqua",
@@ -122,6 +123,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Django :: 4.0",
     "Framework :: Django :: 4.1",
     "Framework :: Django :: 4.2",
+    "Framework :: Django :: 5.0",
     "Framework :: Django CMS",
     "Framework :: Django CMS :: 3.4",
     "Framework :: Django CMS :: 3.5",
@@ -154,6 +156,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Lektor",
     "Framework :: Masonite",
     "Framework :: Matplotlib",
+    "Framework :: MkDocs",
     "Framework :: Nengo",
     "Framework :: Odoo",
     "Framework :: Odoo :: 8.0",
@@ -165,6 +168,11 @@ sorted_classifiers: List[str] = [
     "Framework :: Odoo :: 14.0",
     "Framework :: Odoo :: 15.0",
     "Framework :: Odoo :: 16.0",
+    "Framework :: Odoo :: 17.0",
+    "Framework :: OpenTelemetry",
+    "Framework :: OpenTelemetry :: Distros",
+    "Framework :: OpenTelemetry :: Exporters",
+    "Framework :: OpenTelemetry :: Instrumentations",
     "Framework :: Opps",
     "Framework :: Paste",
     "Framework :: Pelican",
@@ -187,6 +195,9 @@ sorted_classifiers: List[str] = [
     "Framework :: Plone :: Core",
     "Framework :: Plone :: Distribution",
     "Framework :: Plone :: Theme",
+    "Framework :: PySimpleGUI",
+    "Framework :: PySimpleGUI :: 4",
+    "Framework :: PySimpleGUI :: 5",
     "Framework :: Pycsou",
     "Framework :: Pydantic",
     "Framework :: Pydantic :: 1",
@@ -201,6 +212,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Scrapy",
     "Framework :: Setuptools Plugin",
     "Framework :: Sphinx",
+    "Framework :: Sphinx :: Domain",
     "Framework :: Sphinx :: Extension",
     "Framework :: Sphinx :: Theme",
     "Framework :: Trac",
@@ -216,6 +228,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Wagtail :: 3",
     "Framework :: Wagtail :: 4",
     "Framework :: Wagtail :: 5",
+    "Framework :: Wagtail :: 6",
     "Framework :: ZODB",
     "Framework :: Zope",
     "Framework :: Zope2",
@@ -271,6 +284,7 @@ sorted_classifiers: List[str] = [
     "License :: OSI Approved :: Common Public License",
     "License :: OSI Approved :: Eclipse Public License 1.0 (EPL-1.0)",
     "License :: OSI Approved :: Eclipse Public License 2.0 (EPL-2.0)",
+    "License :: OSI Approved :: Educational Community License, Version 2.0 (ECL-2.0)",
     "License :: OSI Approved :: Eiffel Forum License",
     "License :: OSI Approved :: European Union Public Licence 1.0 (EUPL 1.0)",
     "License :: OSI Approved :: European Union Public Licence 1.1 (EUPL 1.1)",
@@ -302,6 +316,7 @@ sorted_classifiers: List[str] = [
     "License :: OSI Approved :: Mozilla Public License 1.1 (MPL 1.1)",
     "License :: OSI Approved :: Mozilla Public License 2.0 (MPL 2.0)",
     "License :: OSI Approved :: Mulan Permissive Software License v2 (MulanPSL-2.0)",
+    "License :: OSI Approved :: NASA Open Source Agreement v1.3 (NASA-1.3)",
     "License :: OSI Approved :: Nethack General Public License",
     "License :: OSI Approved :: Nokia Open Source License",
     "License :: OSI Approved :: Open Group Test Suite License",
@@ -321,6 +336,7 @@ sorted_classifiers: List[str] = [
     "License :: OSI Approved :: Vovida Software License 1.0",
     "License :: OSI Approved :: W3C License",
     "License :: OSI Approved :: X.Net License",
+    "License :: OSI Approved :: Zero-Clause BSD (0BSD)",
     "License :: OSI Approved :: Zope Public License",
     "License :: OSI Approved :: zlib/libpng License",
     "License :: Other/Proprietary License",
@@ -334,6 +350,7 @@ sorted_classifiers: List[str] = [
     "Natural Language :: Bulgarian",
     "Natural Language :: Cantonese",
     "Natural Language :: Catalan",
+    "Natural Language :: Catalan (Valencian)",
     "Natural Language :: Chinese (Simplified)",
     "Natural Language :: Chinese (Traditional)",
     "Natural Language :: Croatian",
@@ -345,6 +362,7 @@ sorted_classifiers: List[str] = [
     "Natural Language :: Finnish",
     "Natural Language :: French",
     "Natural Language :: Galician",
+    "Natural Language :: Georgian",
     "Natural Language :: German",
     "Natural Language :: Greek",
     "Natural Language :: Hebrew",
@@ -450,7 +468,9 @@ sorted_classifiers: List[str] = [
     "Programming Language :: F#",
     "Programming Language :: Forth",
     "Programming Language :: Fortran",
+    "Programming Language :: Go",
     "Programming Language :: Haskell",
+    "Programming Language :: Hy",
     "Programming Language :: Java",
     "Programming Language :: JavaScript",
     "Programming Language :: Kotlin",
@@ -495,6 +515,7 @@ sorted_classifiers: List[str] = [
     "Programming Language :: Python :: 3.10",
     "Programming Language :: Python :: 3.11",
     "Programming Language :: Python :: 3.12",
+    "Programming Language :: Python :: 3.13",
     "Programming Language :: Python :: Implementation",
     "Programming Language :: Python :: Implementation :: CPython",
     "Programming Language :: Python :: Implementation :: IronPython",
@@ -720,6 +741,9 @@ sorted_classifiers: List[str] = [
     "Topic :: Software Development :: Disassemblers",
     "Topic :: Software Development :: Documentation",
     "Topic :: Software Development :: Embedded Systems",
+    "Topic :: Software Development :: Embedded Systems :: Controller Area Network (CAN)",
+    "Topic :: Software Development :: Embedded Systems :: Controller Area Network (CAN) :: CANopen",
+    "Topic :: Software Development :: Embedded Systems :: Controller Area Network (CAN) :: J1939",
     "Topic :: Software Development :: Internationalization",
     "Topic :: Software Development :: Interpreters",
     "Topic :: Software Development :: Libraries",
